==> aws-service-catalog-puppet-0.80.4.tar.gz: aws-service-catalog-puppet-0.80.4/servicecatalog_puppet/workflow/spoke_local_portfolios.py <==
from servicecatalog_puppet.workflow import provisioning as provisioning_tasks

from servicecatalog_puppet.workflow import manifest as manifest_tasks
from servicecatalog_puppet.workflow import generate as generate_tasks


class SpokeLocalPortfolioSectionTask(manifest_tasks.SectionTask):
    def params_for_results_display(self):
        return {
            "puppet_account_id": self.puppet_account_id,
            "manifest_file_path": self.manifest_file_path,
        }

    def requires(self):
        requirements = dict(
            manifest=manifest_tasks.ManifestTask(
                manifest_file_path=self.manifest_file_path,
                puppet_account_id=self.puppet_account_id,
            )
        )

        if self.execution_mode == "hub":
            requirements.update(
                {
                    "generate_shares": generate_tasks.GenerateSharesTask(
                        manifest_file_path=self.manifest_file_path,
                        puppet_account_id=self.puppet_account_id,
                        should_use_sns=self.should_use_sns,
                        should_use_product_plans=self.should_use_product_plans,
                        include_expanded_from=self.include_expanded_from,
                        single_account=self.single_account,
                        is_dry_run=self.is_dry_run,
                        execution_mode=self.execution_mode,
                    ),
                }
            )
        return requirements

    def run(self):
        manifest = self.load_from_input("manifest")
        if self.execution_mode == "hub" and not self.is_dry_run:
            self.info("Generating sharing tasks")
            yield [
                provisioning_tasks.SpokeLocalPortfolioTask(
                    spoke_local_portfolio_name=spoke_local_portfolio_name,
                    manifest_file_path=self.manifest_file_path,
                    puppet_account_id=self.puppet_account_id,
                    should_use_sns=self.should_use_sns,
                    should_use_product_plans=self.should_use_product_plans,
                    include_expanded_from=self.include_expanded_from,
                    single_account=self.single_account,
                    is_dry_run=self.is_dry_run,
                    depends_on=spoke_local_portfolio.get("depends_on", []),
                )
                for spoke_local_portfolio_name, spoke_local_portfolio in manifest.get(
                    "spoke-local-portfolios", {}
                ).items()
            ]
        self.write_output(manifest)

==> aws-service-catalog-puppet-0.84.2.tar.gz: aws-service-catalog-puppet-0.84.2/servicecatalog_puppet/workflow/spoke_local_portfolios.py <==
from servicecatalog_puppet import constants

from servicecatalog_puppet.workflow import provisioning as provisioning_tasks

from servicecatalog_puppet.workflow import manifest as manifest_tasks
from servicecatalog_puppet.workflow import generate as generate_tasks


class SpokeLocalPortfolioSectionTask(manifest_tasks.SectionTask):
    def params_for_results_display(self):
        return {
            "puppet_account_id": self.puppet_account_id,
            "manifest_file_path": self.manifest_file_path,
            "cache_invalidator": self.cache_invalidator,
        }

    def requires(self):
        requirements = dict()
        if self.execution_mode == "hub":
            requirements["generate_shares"] = generate_tasks.GenerateSharesTask(
                manifest_file_path=self.manifest_file_path,
                puppet_account_id=self.puppet_account_id,
                should_use_sns=self.should_use_sns,
                section=constants.SPOKE_LOCAL_PORTFOLIOS,
                cache_invalidator=self.cache_invalidator,
            )
        return requirements

    def run(self):
        if self.execution_mode == "hub" and not self.is_dry_run:
            self.info("Generating sharing tasks")
            yield [
                provisioning_tasks.SpokeLocalPortfolioTask(
                    spoke_local_portfolio_name=spoke_local_portfolio_name,
                    manifest_file_path=self.manifest_file_path,
                    puppet_account_id=self.puppet_account_id,
                    should_use_sns=self.should_use_sns,
                    should_use_product_plans=self.should_use_product_plans,
                    include_expanded_from=self.include_expanded_from,
                    single_account=self.single_account,
                    is_dry_run=self.is_dry_run,
                    depends_on=spoke_local_portfolio.get("depends_on", []),
                    cache_invalidator=self.cache_invalidator,
                )
                for spoke_local_portfolio_name, spoke_local_portfolio in self.manifest.get(
                    "spoke-local-portfolios", {}
                ).items()
            ]

        self.write_output(self.manifest.get("spoke-local-portfolios"))
